Documentation
¶
Overview ¶
This package has the automatically generated clientset.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Clientset ¶
type Clientset struct {
*discovery.DiscoveryClient
// contains filtered or unexported fields
}
Clientset contains the clients for groups. Each group has exactly one version included in a Clientset.
func NewForConfig ¶
NewForConfig creates a new Clientset for the given config.
func NewForConfigOrDie ¶
NewForConfigOrDie creates a new Clientset for the given config and panics if there is an error in the config.
func (*Clientset) Discovery ¶
func (c *Clientset) Discovery() discovery.DiscoveryInterface
Discovery retrieves the DiscoveryClient
func (*Clientset) Jobnetes
deprecated
func (c *Clientset) Jobnetes() jobnetesv1beta.JobnetesV1betaInterface
Deprecated: Jobnetes retrieves the default version of JobnetesClient. Please explicitly pick a version.
func (*Clientset) JobnetesV1beta ¶
func (c *Clientset) JobnetesV1beta() jobnetesv1beta.JobnetesV1betaInterface
JobnetesV1beta retrieves the JobnetesV1betaClient
type Interface ¶
type Interface interface {
Discovery() discovery.DiscoveryInterface
JobnetesV1beta() jobnetesv1beta.JobnetesV1betaInterface
// Deprecated: please explicitly pick a version if possible.
Jobnetes() jobnetesv1beta.JobnetesV1betaInterface
}
Directories
¶
| Path | Synopsis |
|---|---|
|
This package has the automatically generated fake clientset.
|
This package has the automatically generated fake clientset. |
|
This package contains the scheme of the automatically generated clientset.
|
This package contains the scheme of the automatically generated clientset. |
|
typed
|
|
|
jobnetes/v1beta
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
jobnetes/v1beta/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
Click to show internal directories.
Click to hide internal directories.